<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index13.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:36:17 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEOC - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo11.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage13-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader13">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader11.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header>
    <div class="header-area homepage13 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo14.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index1.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="404.html">SEO & Digital Marketing 01</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index2.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index2.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index2.html">SEO & Digital Marketing 02</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn21" href="index3.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn21" href="single-index3.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index4.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index4.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index4.html">SEO & Digital Marketing 04</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index5.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index5.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index5.html">SEO & Digital Marketing 05</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index11.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index11.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index12.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index12.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn21" href="index13.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn21" href="single-index13.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index14.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index14.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index15.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index15.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index6.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index6.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">SEO & Digital Marketing 06</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index7.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index7.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">SEO & Digital Marketing 07</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn21" href="index8.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn21" href="single-index8.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index9.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index9.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index9.html">SEO & Digital Marketing 09</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn21" href="index10.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn21" href="single-index10.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">SEO & Digital Marketing 10</a>
                                 </div>
                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>
              <div class="btn-area">
                <a href="contact.html" class="header-btn21">Get Free Quote <span><i class="fa-solid fa-arrow-right"></i></span></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder13 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo14.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar13">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo14.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="service1.html">Service One</a></li>
          <li><a href="service2.html">Service Two</a></li>
          <li><a href="service3.html">Service Three</a></li>
          <li><a href="service4.html">Service Four</a></li>
          <li><a href="service5.html">Service Five</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn21">Get Started <span><i class="fa-solid fa-arrow-right"></i></span></a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero13-section-area">
    <div class="img2">
        <img src="assets/img/bg/header-bg13.png" alt="" class="header-bg13">
    </div>
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="hero13-header heading19">
                    <h5><img src="assets/img/icons/logo-icons8.svg" alt=""> Top #1 SEO & Advertising Agency</h5>
                    <div class="space16"></div>
                    <h2>We Build Campaigns That Make Brands Unforgettable</h2>
                    <div class="space24"></div>
                    <p>At our agency, we believe that creativity has the power to transform brands and connect them with their audiences in meaningful ways.</p>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="contact.html" class="header-btn21">Our Success Stories <i class="fa-solid fa-arrow-right"></i></a>
                        <a href="contact.html" class="header-btn21 btn2">Contact Us <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-5">
                <div class="img1">
                    <img src="assets/img/all-images/new-img/header-img13.png" alt="">
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->

<!--===== ABOUT AREA STARTS =======-->
<div class="about13-section-area sp1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="images-area" data-aos="zoom-in" data-aos-duration="1000">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/about-img1-h13.png" alt="">
                    </div>
                    <div class="img2">
                        <svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" viewBox="0 0 288 288">
                            <linearGradient id="imagewave" x1="70.711%" x2="0%" y1="70.711%" y2="0%">
                              <stop class="stop-color2" offset="0%" stop-opacity="1"></stop>
                              <stop class="stop-color1" offset="100%" stop-opacity="1"></stop>
                            </linearGradient>
                            <path fill="url(#imagewave)">
                            
                              <animate repeatCount="indefinite" attributeName="d" dur="5s" values="M37.5,186c-12.1-10.5-11.8-32.3-7.2-46.7c4.8-15,13.1-17.8,30.1-36.7C91,68.8,83.5,56.7,103.4,45
                              c22.2-13.1,51.1-9.5,69.6-1.6c18.1,7.8,15.7,15.3,43.3,33.2c28.8,18.8,37.2,14.3,46.7,27.9c15.6,22.3,6.4,53.3,4.4,60.2
                              c-3.3,11.2-7.1,23.9-18.5,32c-16.3,11.5-29.5,0.7-48.6,11c-16.2,8.7-12.6,19.7-28.2,33.2c-22.7,19.7-63.8,25.7-79.9,9.7
                              c-15.2-15.1,0.3-41.7-16.6-54.9C63,186,49.7,196.7,37.5,186z;
                              
                              
                              M51,171.3c-6.1-17.7-15.3-17.2-20.7-32c-8-21.9,0.7-54.6,20.7-67.1c19.5-12.3,32.8,5.5,67.7-3.4C145.2,62,145,49.9,173,43.4
                              c12-2.8,41.4-9.6,60.2,6.6c19,16.4,16.7,47.5,16,57.7c-1.7,22.8-10.3,25.5-9.4,46.4c1,22.5,11.2,25.8,9.1,42.6
                              c-2.2,17.6-16.3,37.5-33.5,40.8c-22,4.1-29.4-22.4-54.9-22.6c-31-0.2-40.8,39-68.3,35.7c-17.3-2-32.2-19.8-37.3-34.8
                              C48.9,198.6,57.8,191,51,171.3z;
                              
                              M37.5,186c-12.1-10.5-11.8-32.3-7.2-46.7c4.8-15,13.1-17.8,30.1-36.7C91,68.8,83.5,56.7,103.4,45
                              c22.2-13.1,51.1-9.5,69.6-1.6c18.1,7.8,15.7,15.3,43.3,33.2c28.8,18.8,37.2,14.3,46.7,27.9c15.6,22.3,6.4,53.3,4.4,60.2
                              c-3.3,11.2-7.1,23.9-18.5,32c-16.3,11.5-29.5,0.7-48.6,11c-16.2,8.7-12.6,19.7-28.2,33.2c-22.7,19.7-63.8,25.7-79.9,9.7
                              c-15.2-15.1,0.3-41.7-16.6-54.9C63,186,49.7,196.7,37.5,186z  "></animate>
                            
                              </path>
                            
                            </svg>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="about13-header heading20">
                    <h5 data-aos="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icons8.svg" alt="">About us</h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">The Minds Behind Your Brand’s Success</h2>
                    <div class="space16"></div>
                    <p data-aos="fade-left" data-aos-duration="1000">At the heart of our agency is a passion for creativity and a relentless drive to push boundaries. We are a team of thinkers, dreamers, and doers who specialize in crafting unique strategies bring brands.</p>
                    <div class="row">
                        <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                            <div class="about-icons">
                                    <div class="icons">
                                        <img src="assets/img/icons/about1-h13.svg" alt="">
                                    </div>
                                    <a href="about.html">Our Story Creative Innovation</a>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                            <div class="about-icons">
                                    <div class="icons">
                                        <img src="assets/img/icons/about2-h13.svg" alt="">
                                    </div>
                                    <a href="about.html">Driven Creativity Focused </a>
                            </div>
                        </div>
                    </div>
                    <div class="space24"></div>
                    <p data-aos="fade-left" data-aos-duration="1100">Our mission is simple: to help brands stand in a crowded market & connect with their audience in meaningful, lasting ways. We’re not just an agency.</p>
                    <div class="space32"></div>
                    <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
                      <a href="contact.html" class="header-btn21">Get Free Quote <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service13-section-area sp2">
  <div class="container">
    <div class="row">
      <div class="col-lg-12">
        <div class="header-area-service space-margin60">
          <div class="heading20">
            <h5 class="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icons8.svg" alt="">Our Services</h5>
            <div class="space16"></div>
            <h2 class="text-anime-style-3">Tailored Solutions For <br class="d-md-block d-none"> Every Brand</h2>
          </div>
          <div class="btn-area1">
            <a href="service1.html" class="header-btn21">View All Service <i class="fa-solid fa-arrow-right"></i></a>
          </div>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons23.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Advertising Campaign Creation</a>
            <div class="space16"></div>
            <p>Our agency offers a comprehensive range of services designed to elevate your brand and maximize its impact. From Brand Strategy</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>01</h2>
          </div>
        </div>
      </div>
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons24.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Brand Strategy & Development</a>
            <div class="space16"></div>
            <p>From Brand Strategy & Creative Campaigns to Digital Marketing and Media Planning, we bring a unique blend of innovation expertise</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>02</h2>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons25.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Targeted Media Buying & Planning</a>
            <div class="space16"></div>
            <p>Whether you need targeted social media campaigns, eye-catching visuals, or data-driven performance optimization.</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>03</h2>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons26.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Graphic Design & Visual Branding</a>
            <div class="space16"></div>
            <p>Each service is tailored meet your specific goals, ensuring that your brand stands out, engages, and drives measurable results</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>04</h2>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons27.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Influencer Marketing Partnerships</a>
            <div class="space16"></div>
            <p>Whether you need targeted social media campaigns, eye-catching visuals, or data-driven performance optimization.</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>05</h2>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1300">
        <div class="service13-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icons28.svg" alt="">
          </div>
          <div class="space32"></div>
          <div class="content-area">
            <a href="service1.html" class="head">Video Production & Animation</a>
            <div class="space16"></div>
            <p>Our agency offers a comprehensive range of services designed to elevate your brand and maximize its impact. From Brand Strategy</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-arrow-right"></i></a>
            <h2>06</h2>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== SERVICE AREA ENDS =======-->

<!--===== WORK AREA STARTS =======-->
<div class="work13-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-5 m-auto">
        <div class="work-haader text-center heading20 space-margin60">
          <h5 data-aos="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icons8.svg" alt="">Our Project</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">The Work That Drives Brands Forward</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-5 col-md-6" data-aos="zoom-in" data-aos-duration="700">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img1-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img2-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img3-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img4-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-5 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img5-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="project13-boxrea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/service-img6-h13.png" alt="">
          </div>
          <div class="content-area">
            <span>#Advertising Agency</span>
            <div class="space16"></div>
            <a href="service1.html">A branding & visual <br> design overhaul.</a>
          </div>
        </div>
      </div>
      <div class="col-lg-12">
        <div class="btn-area1 text-center">
          <a href="service1.html" class="header-btn21">View All Projects <i class="fa-solid fa-arrow-right"></i></a>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== WORK AREA ENDS =======-->

<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial13-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-5">
        <div class="testimonial13-header heading20 space-margin60">
          <h5 data-aos="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icons8.svg" alt="">Testimonials</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">Success Stories from <br class="d-md-block d-none"> Our Partners</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-12">
        <div class="testimonial13-slider owl-carousel">
          <div class="testimonial13-boxrea">
            <ul>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
            </ul>
            <div class="space24"></div>
            <p>“Our clients’ success is our greatest achievement. We pride ourselves on building strong, collaborative relationships that drive exceptional results. From innovative branding strategies powerful multi-channel campaigns, we work tirelessly to exceed expectations.”</p>
            <div class="space24"></div>
            <div class="name-area">
              <div class="name-text">
                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                <div class="content">
                  <a href="#">Arturo Reynolds</a>
                  <div class="space12"></div>
                  <p>Company Owner</p>
                </div>
              </div>
              <img src="assets/img/icons/quito8.svg" alt="" class="quito8">
            </div>
          </div>
          <div class="testimonial13-boxrea">
            <ul>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
            </ul>
            <div class="space24"></div>
            <p>“Our clients consistently commend us for our ability to turn ambitious ideas into successful campaigns. Their feedback highlights dedication to understanding their unique needs, crafting tailored solutions, and delivering exceptional results pride in our collaborative approach.”</p>
            <div class="space24"></div>
            <div class="name-area">
              <div class="name-text">
                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                <div class="content">
                  <a href="#">Stewart Parisian</a>
                  <div class="space12"></div>
                  <p>Company Owner</p>
                </div>
              </div>
              <img src="assets/img/icons/quito8.svg" alt="" class="quito8">
            </div>
          </div>
          <div class="testimonial13-boxrea">
            <ul>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
            </ul>
            <div class="space24"></div>
            <p>“Our clients’ success is our greatest achievement. We pride ourselves on building strong, collaborative relationships that drive exceptional results. From innovative branding strategies powerful multi-channel campaigns, we work tirelessly to exceed expectations.”</p>
            <div class="space24"></div>
            <div class="name-area">
              <div class="name-text">
                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                <div class="content">
                  <a href="#">Arturo Reynolds</a>
                  <div class="space12"></div>
                  <p>Company Owner</p>
                </div>
              </div>
              <img src="assets/img/icons/quito8.svg" alt="" class="quito8">
            </div>
          </div>
          <div class="testimonial13-boxrea">
            <ul>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
              <li><i class="fa-solid fa-star"></i></li>
            </ul>
            <div class="space24"></div>
            <p>“Our clients consistently commend us for our ability to turn ambitious ideas into successful campaigns. Their feedback highlights dedication to understanding their unique needs, crafting tailored solutions, and delivering exceptional results pride in our collaborative approach.”</p>
            <div class="space24"></div>
            <div class="name-area">
              <div class="name-text">
                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                <div class="content">
                  <a href="#">Stewart Parisian</a>
                  <div class="space12"></div>
                  <p>Company Owner</p>
                </div>
              </div>
              <img src="assets/img/icons/quito8.svg" alt="" class="quito8">
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team13-section-area sp2">
  <div class="container">
    <div class="row">
      <div class="col-lg-6 m-auto">
        <div class="team13-header text-center heading20 space-margin60">
          <h5><img src="assets/img/icons/logo-icons8.svg" alt="">Our Team</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">Our Team: Where Creativity Meets Strategy</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="team13-boxarea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/team-img1-h13.png" alt="">
          </div>
          <div class="space24"></div>
          <div class="content-area">
            <a href="team.html">Krystal Hermann</a>
            <div class="space12"></div>
            <p>CEO & Founder</p>
          </div>
          <ul>
            <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
          </ul>
        </div>
      </div>
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="team13-boxarea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/team-img2-h13.png" alt="">
          </div>
          <div class="space24"></div>
          <div class="content-area">
            <a href="team.html">Arnold Beier V</a>
            <div class="space12"></div>
            <p>CEO & Founder</p>
          </div>
          <ul>
            <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
          </ul>
        </div>
      </div>
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="team13-boxarea">
          <div class="img1 image-anime">
            <img src="assets/img/all-images/new-img/team-img3-h13.png" alt="">
          </div>
          <div class="space24"></div>
          <div class="content-area">
            <a href="team.html">Lucas Hagenes</a>
            <div class="space12"></div>
            <p>CEO & Founder</p>
          </div>
          <ul>
            <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
          </ul>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== TEAM AREA ENDS =======-->

<!--===== OTHERS AREA STARTS =======-->
<div class="others13-section-area sp1">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-lg-5">
        <div class="others-header heading20">
          <h2 class="text-anime-style-3">All Your Client's Marketing Data in One Place</h2>
          <div class="space16"></div>
          <p data-aos="fade-left" data-aos-duration="1000">Marketing moves fast, and so do we. With 75+ marketing integration and new releases each month, we’ll keep you up- to-date with all your client’s data in one place.</p>
          <div class="space32"></div>
          <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
            <a href="contact.html" class="header-btn21">Get A Free Proposal <i class="fa-solid fa-arrow-right"></i></a>
          </div>
        </div>
      </div>
      <div class="col-lg-1"></div>
      <div class="col-lg-6">
        <div class="row">
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img1-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img2-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img3-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img4-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img5-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img6-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img7-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img8-h13.png" alt="">
            </div>
          </div>
          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
            <div class="img1">
              <img src="assets/img/all-images/new-img/others-img9-h13.png" alt="">
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== OTHERS AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog13-section-area sp2">
  <div class="container">
      <div class="row">
          <div class="col-lg-5 m-auto">
              <div class="blog4-header text-center heading20 space-margin60">
                  <h5 data-aos="fade-up" data-aos-duration="1000"><img src="assets/img/icons/logo-icons8.svg" alt="">Blog & News</h5>
                  <div class="space16"></div>
                  <h2 class="text-anime-style-3">Agency Insights: Trends, Tips & More</h2>
              </div>
          </div>
      </div>
      <div class="row">
        <div class="col-lg-4 col-md-6" data-aos="zoom-out" data-aos-duration="800">
          <div class="blog-auhtor-boxarea">
            <ul>
              <li><a href="#"><i class="fa-regular fa-circle-user"></i>John Doe</a></li>
              <li class="m-0"><a href="#"><i class="fa-solid fa-calendar-days"></i> 12 Feb 2024</a></li>
            </ul>
            <div class="space24"></div>
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/blog-img1-h13.png" alt="">
            </div>
            <div class="space24"></div>
            <div class="blog-content-area">
              <a href="blog-single.html">Unleashing Creativity: The Art and Science of Effective Advertising</a>
              <div class="space16"></div>
              <p>t’s a delicate balance & science, combining creative vision with data-driven strategy.</p>
              <div class="space24"></div>
              <a href="blog-single.html" class="readmore">Learn More<i class="fa-solid fa-arrow-right"></i></a>
            </div>
          </div>
        </div>

        <div class="col-lg-4 col-md-6" data-aos="zoom-out" data-aos-duration="1000">
          <div class="blog-auhtor-boxarea">
            <ul>
              <li><a href="#"><i class="fa-regular fa-circle-user"></i>John Doe</a></li>
              <li><a href="#"><i class="fa-solid fa-calendar-days"></i> 12 Feb 2024</a></li>
            </ul>
            <div class="space24"></div>
            <div class="img1 image-anime">
                <img src="assets/img/all-images/new-img/blog-img2-h13.png" alt="">
             </div>
            <div class="blog-content-area">
              <div class="space24"></div>
              <a href="blog-single.html">Exploring Strategies, Trends, and Insights to Elevate Your Brand</a>
              <div class="space16"></div>
              <p>In this blog, we delve into the elements that make advertising truly impactful. </p>
              <div class="space24"></div>
              <a href="blog-single.html" class="readmore">Learn More<i class="fa-solid fa-arrow-right"></i></a>
            </div>
          </div>
        </div>
        <div class="col-lg-4 col-md-6" data-aos="zoom-out" data-aos-duration="1200">
          <div class="blog-auhtor-boxarea">
            <ul>
              <li><a href="#"><i class="fa-regular fa-circle-user"></i>John Doe</a></li>
              <li><a href="#"><i class="fa-solid fa-calendar-days"></i> 12 Feb 2024</a></li>
            </ul>
            <div class="space24"></div>
            <div class="img1 image-anime">
                <img src="assets/img/all-images/new-img/blog-img3-h13.png" alt="">
             </div>
            <div class="blog-content-area">
              <div class="space24"></div>
              <a href="blog-single.html">Unleashing Creativity: Trends Shaping the Future of Advertising</a>
              <div class="space16"></div>
              <p>Explore how emerging trends and innovative strategies are revolutionizing the advertising</p>
              <div class="space24"></div>
              <a href="blog-single.html" class="readmore">Learn More<i class="fa-solid fa-arrow-right"></i></a>
            </div>
          </div>
        </div>
      </div>
  </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta13-section-area sp1">
  <img src="assets/img/bg/cta13-bg1.png" alt="" class="cta13-bg1">
  <div class="container">
    <div class="row">
      <div class="col-lg-8 m-auto">
        <div class="cta13-header text-center heading20">
          <h2 class="text-anime-style-3">Take Your Brand To The Next Level! <br class="d-lg-block d-none">To Begin Your Success Story.</h2>
            <div class="space16"></div>
          <p data-aos="fade-up" data-aos-duration="1000">Ready to elevate your brand and achieve exceptional results? Our team <br class="d-lg-block d-none"> of creative experts is here to turn your vision into reality. </p>
          <div class="space40"></div>
          <div class="btn-area1" data-aos="fade-up" data-aos-duration="1200">
            <a href="contact.html" class="header-btn21">Get Started Today <i class="fa-solid fa-arrow-right"></i></a>
            <a href="contact.html" class="header-btn21 btn2">Request a Consultation <i class="fa-solid fa-arrow-right"></i></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer13-section-area">
  <div class="container">
    <div class="row">
      <div class="col-lg-3 col-md-6">
        <div class="footer-logo-area">
          <img src="assets/img/logo/logo14.png" alt="">
          <p>By optimizing content, leveraging relevant keywords, and adhering to best practices, businesses can secure prominent position (SEO)</p>
          <ul>
            <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
            <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
          </ul>
        </div>
      </div>

      <div class="col-lg-2 col-md-6">
        <div class="footer-logo-area1">
          <h3>About Link</h3>
          <ul>
            <li><a href="blog.html">Our Blog</a></li>
            <li><a href="about.html">About Us</a></li>
            <li><a href="service1.html">Services</a></li>
            <li><a href="case.html">Marketing</a></li>
            <li><a href="testimonials.html">Testimonials</a></li>
            <li><a href="contact.html">Contact Us</a></li>
          </ul>
        </div>
      </div>

      <div class="col-lg-3 col-md-6">
        <div class="footer-logo-area2">
          <h3>Get in touch</h3>
          <ul>
            <li><a href="404-4.html"><img src="assets/img/icons/email.svg" alt=""><span>Infoseoc@gmail.com</span></a></li>
            <li><a href="#"><img src="assets/img/icons/location.svg" alt=""><span>8708 Technology Forest <br class="d-lg-block d-none"> Pl Suite 125 -G, The <br class="d-lg-block d-none"> Woodlands, TX 773</span></a></li>
            <li><a href="tel:123-456-7890"><img src="assets/img/icons/phone.svg" alt=""><span>123-456-7890</span></a></li>
          </ul>
        </div>
      </div>
      <div class="col-lg-3 col-md-6">
        <div class="footer-logo-area3">
          <h3>Subscribe Our Newsletter</h3>
          
          <form action="#">
            <input type="text" placeholder="Enter Your email">
            <div class="space16"></div>
            <button class="header-btn21"> Subscribe <span><i class="fa-solid fa-arrow-right"></i></span></button>
          </form>
        </div>
      </div>
    </div>
    <div class="space50 d-lg-block d-none"></div>
    <div class="space40 d-lg-none d-block"></div>
    <div class="row">
      <div class="col-lg-12">
        <div class="copyright-area">
          <div class="pera">
            <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
          </div>
          <ul>
            <li><a href="#">Terms & Conditions</a></li>
            <li><a href="#" class="m-0"> Privacy Policy </a></li>
          </ul>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== FOOTER AREA ENDS =======-->


<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index13.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:37:16 GMT -->
</html>